Client

Struct Client 

pub struct Client { /* private fields */ }
The main entry point into this crate. Hold the access token currently base_url needs to be post fixed with /api for this library to actually work. TODO: that should be fixed.

Implementations

Source

impl Client

pub fn call<R: Request>(&self, request: R) -> Result<R::Response>

This is our generic calling function for the API, the error handling is somewhat ass since it doesn’t use https://docs.rs/ureq/latest/ureq/enum.Error.html#examples because the error enum in this repository somehow caused an inifinite loop with the transformations.

TODO: The error should properly parse the actually useful error responses from the API.

pub fn fetch_all<R, T>(&self, request: R) -> Result<Vec<T>>
where R: Request<Response = PaginatedResponse<Vec<T>>> + Paginated + Clone, T: DeserializeOwned,

Consumes all pages of the API in sequence and assembles a flat Vec of all pages.